/**
 * Standalone light-themed version.
 * Includes light variables and core, left as CSS variables
 * so the theming can be adjusted at runtime.
 */

:root {
  --background-body: #ffffff;
  --background: #efefef;
  --background-alt: #f7f7f7;

  --selection: #9e9e9e;

  --text-main: #363636;
  --text-bright: #000000;

  --links: #0076d1;
  --focus: #0096bfab;
  --border: #dbdbdb;
  --code: #000000;

  --animation-duration: 0.1s;
  --button-hover: #dddddd;

  --scrollbar-thumb: rgb(213, 213, 213);
  --scrollbar-thumb-hover: rgb(196, 196, 196);

  --form-placeholder: #949494;
  --form-text: #000000;

  --variable: #39a33c;
  --highlight: #ffff00;
}

body {
  font-family: system-ui, -apple-system, BlinkMacSystemFont, 'Segoe UI', 'Roboto', 'Oxygen', 'Ubuntu', 'Cantarell', 'Fira Sans', 'Droid Sans', 'Helvetica Neue', sans-serif;
  line-height: 1.4;

  max-width: 800px;
  margin: 20px auto;
  padding: 0 10px;

  color: var(--text-main);
  background: var(--background-body);

  text-rendering: optimizeLegibility;
}

button, input, textarea {
  transition: background-color var(--animation-duration) linear,
              border-color var(--animation-duration) linear,
              color var(--animation-duration) linear,
              box-shadow var(--animation-duration) linear,
              transform var(--animation-duration) ease;
}

h1 {
  font-size: 2.2em;
  margin-top: 0;
}

h1,
h2,
h3,
h4,
h5,
h6 {
  margin-bottom: 12px;
}

h1,
h2,
h3,
h4,
h5,
h6,
strong {
  color: var(--text-bright);
}

h1,
h2,
h3,
h4,
h5,
h6,
b,
strong,
th {
  font-weight: 600;
}

q:before {
   content: none;
}

q:after {
   content: none;
}

blockquote , q{
  border-left: 4px solid var(--focus);
  margin: 1.5em 0em;
  padding: 0.5em 1em;
  font-style: italic;
}

blockquote > footer {
  margin-top: 10px;
  font-style: normal;
}

blockquote cite {
  font-style: normal;
}

address {
  font-style: normal;
}

a[href^='mailto']::before {
  content: '📧 ';
}

a[href^='tel']::before {
  content: '📞 ';
}

a[href^='sms']::before {
  content: '💬 ';
}

mark {
  background-color: var(--highlight);
  border-radius: 2px;
  padding: 0px 2px 0px 2px;
  color: #000000;
}

button,
input[type='submit'],
input[type='button'],
input[type='checkbox'] {
  cursor: pointer;
}

input:not([type='checkbox']):not([type='radio']),
select {
  display: block;
}

input,
select,
button,
textarea {
  color: var(--form-text);
  background-color: var(--background);

  font-family: inherit;
  font-size: inherit;

  margin-right: 6px;
  margin-bottom: 6px;
  padding: 10px;

  border: none;
  border-radius: 6px;
  outline: none;
}

input:not([type='checkbox']):not([type='radio']),
select,
button,
textarea {
  -webkit-appearance: none;
}

textarea {
  margin-right: 0;
  width: 100%;
  box-sizing: border-box;
  resize: vertical;
}

button,
input[type='submit'],
input[type='button'] {
  padding-right: 30px;
  padding-left: 30px;
}

button:hover,
input[type='submit']:hover,
input[type='button']:hover {
  background: var(--button-hover);
}

input:focus,
select:focus,
button:focus,
textarea:focus {
  box-shadow: 0 0 0 2px var(--focus);
}

input[type='checkbox']:active,
input[type='radio']:active,
input[type='submit']:active,
input[type='button']:active,
button:active {
  transform: translateY(2px);
}

input:disabled,
select:disabled,
button:disabled,
textarea:disabled {
  cursor: not-allowed;
  opacity: 0.5;
}

::-webkit-input-placeholder {
  color: var(--form-placeholder);
}

:-ms-input-placeholder {
  color: var(--form-placeholder);
}

::-ms-input-placeholder {
  color: var(--form-placeholder);
}

::placeholder {
  color: var(--form-placeholder);
}

a {
  text-decoration: none;
  color: var(--links);
}

a:hover {
  text-decoration: underline;
}

code, samp, time {
  background:  var(--background);
  color: var(--code);
  padding: 2.5px 5px;
  border-radius: 6px;
  font-size: 1em;
}

pre > code {
  padding: 10px;
  display: block;
  overflow-x: auto;
}

var {
  color: var(--variable);
  font-style: normal;
  font-family: monospace;
}

kbd {
  background: var(--background);
  border: 1px solid var(--border);
  border-radius: 2px;
  color: var(--text-main);
  padding: 2px 4px 2px 4px;
}

img {
  max-width: 100%;
  height: auto;
}

hr {
  border: none;
  border-top: 1px solid var(--border);
}

table {
  border-collapse: collapse;
  margin-bottom: 10px;
  width: 100%;
}

td,
th {
  padding: 6px;
  text-align: left;
}

th {
  border-bottom: 1px solid var(--border);
}

tbody tr:nth-child(even) {
  background-color: var(--background-alt);
}

::-webkit-scrollbar {
  height: 10px;
  width: 10px;
}

::-webkit-scrollbar-track {
  background: var(--background);
  border-radius: 6px;
}

::-webkit-scrollbar-thumb {
  background: var(--scrollbar-thumb);
  border-radius: 6px;
}

::-webkit-scrollbar-thumb:hover {
  background: var(--scrollbar-thumb-hover);
}

::-moz-selection {
  background-color: var(--selection);
}

::selection {
  background-color: var(--selection);
}

/*# sourceMappingURL=light.standalone.css.map */
