/*
MousikóFídi
Copyright (C) 2019  Hristos N. Triantafillou

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

audio {
    margin-top: 25px;
    width: 100%;
}

div#player {
    background-color: #333;
    border-top-left-radius: 4px;
    border-top-right-radius: 4px;
    box-shadow: 4px 4px 2px 2px rgba(0, 0, 0, 0.2);
    padding-bottom: 10px;
    position: -webkit-sticky;
    position: sticky;
    bottom: 0;
    z-index: 4;
}

div#player audio {
    width: 95%;
}

p#now-playing {
    color: #fff;
    margin: 0 auto;
    margin-bottom:-10px;
    padding-top: 12px
}

div#videoplayer {
    margin: 0 auto;
    width: 100%;
}

video {
    margin-top: 25px;
    width: 100% !important;
    height: auto !important;
}

footer {
    font-size: 0.5em;
    margin-top: 25px;
}

div#audio-time-link {
    margin-top: 25px;
}


div#player button {
    display: inline-block;
}

form#playlistctl input {
    display: inline-block;
}

form#theme-picker label select {
    margin: 0 auto;
}

form#icons-toggle {
    margin-top: 25px;
}

form#icons-toggle label select {
    margin: 0 auto;
}

nav {
    height: 50px;
    margin-bottom: 0;
    padding-bottom: 0;
    position: -webkit-sticky;
    position: sticky;
    top: 0;
    z-index: 34;
}

nav ul {
    margin-bottom: 0;
    margin-top: 0;
    list-style-type: none;
    overflow: hidden;
    background-color: #333;
    padding-left: 0;
    display: inline-block;
    width: 100%;
}

nav ul li {
    float: left;
}

nav ul li#logo {
    float: right;
}

nav ul li#logo a#logo {
    padding: 0;
}

nav ul li#logo a#logo {
    -webkit-transition: none;
    transition: none;
    float: right;
    color: darkgray;
}

nav ul li#logo a#logo:hover {
    background-color: #333;
}

nav ul li a {
    display: block;
    color: white;
    text-align: center;
    padding: 14px 16px;
    text-decoration: none;
}

nav ul li a:hover {
    -webkit-transition: background-color 0.5s ease;
    transition: background-color 0.5s ease;
    background-color: #111;
}

nav ul li a img {
    margin-top: 9px;
    margin-right: 9px;
    height: 32px;
    width: 32px;
}

a:hover {
    text-decoration: none;
}

div#content {
    min-height: 315px;
    margin-top: 20px;
}

div#top-link {
    z-index: 16;
    float: right;
    position: -webkit-sticky;
    position: sticky;
    bottom: 30px;
    margin-right: 10px;
}

div#top-link a {
    z-index: 16;
    width: 0;
    height: 0;
    border-left: 25px solid transparent;
    border-right: 25px solid transparent;
    border-bottom: 25px solid grey;
}

input#bulk-add {
    margin: 0 auto;
    margin-bottom: 25px;
}

select#to-load {
    margin: 0 auto;
    margin-bottom: 10px;
}

div.anchor {
    bottom: 100px;
    position: relative;
}

div.play-arrow {
    width: 0;
    height: 0;
    border-top: 15px solid transparent;
    border-bottom: 15px solid transparent;
    border-left: 15px solid green;
    float: left;
    margin-left: 14px;
    margin-top: 5px;
}

input.plus {
    color: #41adff;
    font-size: 1.9em;
    margin: 0 0 0 10px;
    padding: 0;
    background: none !important;
    width: 20px;
}

input.plus-btn {
    color: #41adff;
    font-size: 1.9em;
    margin: 0 auto;
}

input.X {
    margin: 0 0 0 20px;
    padding: 0;
    font-size: 1.4em;
    background: none !important;
}

td.title-mobile {
    display: none;
}

.center {
    text-align: center;
}

.bold {
    font-weight: bold;
}

.green {
    color: green;
}

.hidden {
    display: none;
}

.initialsize {
    font-size: initial;
    font-weight: initial;
}

.mobile-show {
    display: none;
}

.red {
    color: red;
}

/* THANKS: https://gist.github.com/gokulkrishh/242e68d1ee94ad05f488 */

@media (min-width: 481px) and (max-width: 767px),(min-width: 320px) and (max-width: 480px) {
    button#mobile-next, button#mobile-prev, button#mobile-repeat, button#mobile-shuffle,
    button#mobile-vid-next, button#mobile-vid-prev, button#mobile-vid-repeat, button#mobile-vid-shuffle {
        width: 45%;
    }

    td.title-regular {
        display: none;
    }

    td.title-mobile {
        display: block;
    }

    .mobile-big {
        font-size: 1.5em;
    }

    .mobile-show {
        display: block;
    }

    .mobile-hide {
        display: none;
    }

    .mobile {
        padding: 0;
    }
}
