{% extends 'base.html' %}
{% block content %}

  <h4 class="center">Settings</h4>

  <form class="center" id="theme-picker" action="{{ url_for('.settings_edit') }}" method="post">
    <label>{% if icons %}<i class="fas fa-palette"></i> {% endif %}Select your theme:
      <select class="center" name="theme">
        {% for t in themes %}
          <option value="{{ t.name }}"{% if t.name in theme %} selected{% endif %}>{{ t.proper }}</option>
        {% endfor %}
      </select>
      <input style="margin:0 auto; margin-top:10px;" class="center" type="submit" value="Submit">
    </label>
  </form>

  <form class="center" id="icons-toggle" action="{{ url_for('.settings_edit') }}" method="post">
    <label>{% if icons %}<i class="fas fa-icons"></i> {% endif %}Enable or disable icons:
      <select class="center" name="icons">
        <option value="disabled"{% if not icons %} selected{% endif %}>Disabled</option>
        <option value="enabled"{% if icons %} selected{% endif %}>Enabled</option>
      </select>
      <input style="margin:0 auto; margin-top:10px;" class="center" type="submit" value="Submit">
    </label>
  </form>

{% endblock %}
