<div data-nowplaying-num="0" id="video-now-playing-num"></div>
<div data-randorder="none" id="vid-randorder"></div>
<div class="center">
  <video id="video"{% if autoplay %} autoplay{% endif %}{% if preload_video %} preload="auto"{% endif %} controls>
    <source>
    <p>Your browser doesn't support HTML5 video.</p>
  </video>
  <div id="videoplayer"></div>
  <div class="mobile-hide">
    <button data-cmd="prev" id="vid-prev" title="Click to skip to the previous track in the list.">{% if icons %}<i class="fas fa-step-backward"></i> {% endif %}Previous</button>
    <button data-stat="off" id="vid-repeat" title="Click to toggle between no repeat, repeat one track, and repeat all tracks.">{% if icons %}<i class="fas fa-redo"></i> {% endif %}No Repeat</button>  
    <button data-stat="off" id="vid-shuffle" title="Click to toggle between a shuffled track order on and off.">{% if icons %}<i class="fas fa-random"></i> {% endif %}Shuffle Off</button>
    <button data-cmd="fwd" id="vid-next" title="Click to skip to the next track in the list.">Next{% if icons %} <i class="fas fa-step-forward"></i>{% endif %}</button>
  </div>

  <div class="mobile-show">
    <div>
      <button data-cmd="prev" id="mobile-vid-prev" title="Click to skip to the previous track in the list.">{% if icons %}<i class="fas fa-step-backward"></i> {% endif %}Previous</button>
      <button data-cmd="fwd" id="mobile-vid-next" title="Click to skip to the next track in the list.">Next{% if icons %} <i class="fas fa-step-forward"></i>{% endif %}</button>
    </div>
    <div>
      <button data-stat="off" id="mobile-vid-repeat" title="Click to toggle between no repeat, repeat one track, and repeat all tracks.">{% if icons %}<i class="fas fa-redo"></i> {% endif %}No Repeat</button>
      <button data-stat="off" id="mobile-vid-shuffle" title="Click to toggle between a shuffled track order on and off.">{% if icons %}<i class="fas fa-random"></i> {% endif %}Shuffle Off</button>
    </div>
  </div>

  {% if link_button %}
    <button id="video-time-link" title="Click this button to have a link to this track at the current time put into your clipboard.">{% if icons %}<i class="fas fa-link"></i> {% endif %}Current Time Link</button>
  {% endif %}
</div>
