nav {
    margin-bottom: 60px;
}

input.plus {
    width: initial;
}

select#to-load {
    max-width: 100%;
}

/* Taken from: https://fonts.googleapis.com/css?family=Press+Start+2P */

/* cyrillic-ext */
@font-face {
  font-family: 'Press Start 2P';
  font-style: normal;
  font-weight: 400;
  src: url('/PressStart2P-Regular.ttf'), url('/static/PressStart2P-Regular.ttf');
  unicode-range: U+0460-052F, U+1C80-1C88, U+20B4, U+2DE0-2DFF, U+A640-A69F, U+FE2E-FE2F;
}

/* cyrillic */
@font-face {
  font-family: 'Press Start 2P';
  font-style: normal;
  font-weight: 400;
  src: url('/PressStart2P-Regular.ttf'), url('/static/PressStart2P-Regular.ttf');
  unicode-range: U+0400-045F, U+0490-0491, U+04B0-04B1, U+2116;
}

/* greek */
@font-face {
  font-family: 'Press Start 2P';
  font-style: normal;
  font-weight: 400;
  src: url('/PressStart2P-Regular.ttf'), url('/static/PressStart2P-Regular.ttf');
  unicode-range: U+0370-03FF;
}

/* latin-ext */
@font-face {
  font-family: 'Press Start 2P';
  font-style: normal;
  font-weight: 400;
  src: url('/PressStart2P-Regular.ttf'), url('/static/PressStart2P-Regular.ttf');
  unicode-range: U+0100-024F, U+0259, U+1E00-1EFF, U+2020, U+20A0-20AB, U+20AD-20CF, U+2113, U+2C60-2C7F, U+A720-A7FF;
}

/* latin */
@font-face {
  font-family: 'Press Start 2P';
  font-style: normal;
  font-weight: 400;
  src: url('/PressStart2P-Regular.ttf'), url('/static/PressStart2P-Regular.ttf');
  unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02BB-02BC, U+02C6, U+02DA, U+02DC, U+2000-206F, U+2074, U+20AC, U+2122, U+2191, U+2193, U+2212, U+2215, U+FEFF, U+FFFD;
}

@media (min-width: 768px) and (max-width: 1024px) {
    .mobile-big {
        font-size: 1.5em;
    }

    .mobile-hide {
        display: none;
    }

    .mobile {
        padding: 0;
    }
}
