<div class="center" id="player">
  <p id="now-playing" title="The status of the current track.">Paused: <span class="bold" id="playing-title" title="The title of the current track."></span></p>
  <div data-nowplaying-num="0" id="now-playing-num"></div>
  <div data-randorder="none" id="randorder"></div>
  <audio{% if autoplay %} autoplay{% endif %}{% if preload_audio %} preload="auto"{% endif %} id="audio" controls>
    Your browser does not support the <code>audio</code> element.
  </audio>
  <div class="mobile-hide">
    <button data-cmd="prev" id="prev" title="Click to skip to the previous track in the list.">{% if icons %}<i class="fas fa-step-backward"></i> {% endif %}Previous</button>
    <button data-stat="off" id="repeat" title="Click to toggle between no repeat, repeat one track, and repeat all tracks.">{% if icons %}<i class="fas fa-redo"></i> {% endif %}No Repeat</button>
    <button data-stat="off" id="shuffle" title="Click to toggle between a shuffled track order on and off.">{% if icons %}<i class="fas fa-random"></i> {% endif %}Shuffle Off</button>
    <button data-cmd="fwd" id="next" title="Click to skip to the next track in the list.">Next{% if icons %} <i class="fas fa-step-forward"></i>{% endif %}</button>
  </div>
  <div class="mobile-show">
    <div>
      <button data-cmd="prev" id="mobile-prev" title="Click to skip to the previous track in the list.">{% if icons %}<i class="fas fa-step-backward"></i> {% endif %}Previous</button>
      <button data-cmd="fwd" id="mobile-next" title="Click to skip to the next track in the list.">Next{% if icons %} <i class="fas fa-step-forward"></i>{% endif %}</button>
    </div>
    <div>
      <button data-stat="off" id="mobile-repeat" title="Click to toggle between no repeat, repeat one track, and repeat all tracks.">{% if icons %}<i class="fas fa-redo"></i> {% endif %}No Repeat</button>
      <button data-stat="off" id="mobile-shuffle" title="Click to toggle between a shuffled track order on and off.">{% if icons %}<i class="fas fa-random"></i> {% endif %}Shuffle Off</button>
    </div>
  </div>
</div>

{% if link_button %}
  <div id="audio-time-link" class="center">
    <button id="audio-time-link" title="Click this button to have a link to this track at the current time put into your clipboard.">
      {% if icons %}<i class="fas fa-link"></i> {% endif %}Current Time Link
    </button>
  </div>
{% endif %}
