/*
Terminal.css for MousikóFídi
Copyright (C) 2019  ogenfald

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

body {
        background-color: #1d1f21;
        color: lime;
        font-family: monospace;
        font-size: large;
}

a:link {
        color : lime;
}

a:visited {
        color: lime;
}

input[type=text] {
        border: 2px solid lime;
        background-color: #1d1f21;
        color: lime;
}

input[type=submit] {
        border: 2px solid lime;
        background-color: #1d1f21;
        color: lime;
}

select {
        border: 2px solid lime;
        background-color: #1d1f21;
        color: lime;
}

button {
        border: 2px solid lime;
        background-color: #1d1f21;
        color: lime;
}
